<?php

namespace Drupal\content_model_documentation\Commands;

use Drupal\content_model_documentation\CmDocumentMover\CmDocumentExport;
use Drupal\content_model_documentation\CmDocumentMover\CmDocumentImport;
use Drush\Commands\DrushCommands;

/**
 * Drush command file.
 */
class CmDocumentationCommands extends DrushCommands {

  /**
   * Exports the identified Content Model Document.
   *
   * @param int $id
   *   The cm document id to export.
   *
   * @command content-model-documentation:export
   * @usage drush content-model-documentation:export 123
   *   Export Content Model Document id 123 to the export directory.
   * @aliases cm-doc-export
   */
  public function export(int $id) {
    try {
      // Check that we have what it needs to export.
      CmDocumentExport::canExport();
      // It can export so can safely proceed.
      $msg = dt('Exported CM Document: ') . "[$id] => " . CmDocumentExport::export($id);
    }
    catch (\Exception $e) {
      $vars = [
        '@error' => $e->getMessage(),
      ];
      $msg = dt("Content Model Document export exception:  @error", $vars);
    }

    return $msg;
  }

  /**
   * Imports the identified Content Model Document.
   *
   * @param string $alias
   *   The alias of the Content Model Document to import.
   *
   * @command content-model-documentation:import
   * @usage drush content-model-documentation:import 'the/path/of/the/document'
   *   Import the Content Model Document that would have this alias.
   * @aliases cm-doc-import
   */
  public function import(string $alias) {
    try {
      // Check that we have what it needs to export.
      CmDocumentImport::canImport();
      // It can import so can safely proceed.
      $msg = dt('Import CM Document: ') . CmDocumentImport::import($alias, TRUE, TRUE);
    }
    catch (\Exception $e) {
      $vars = [
        '@error' => $e->getMessage(),
      ];

      $msg = dt("Content Model Document import exception:  @error", $vars);
    }

    return $msg;
  }

}
